/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */
/*
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+                     LIBREOFFICE HELP IN BROWSER                   +
+                          DEFAULT STYLESHEET                       +
+                           WESTERN LANGUAGES                       +
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*/

body,
p,
h1,
h2,
h3,
h4,
h5,
h6,
.listitem,
.listitemintable,
.tablecontent,
.tablecontentintable {
    font-family: "Segoe UI", Ubuntu, Cantarell, "Noto Sans", "DejaVu Sans", "Lucida Sans Unicode", "Helvetica Neue", Helvetica, Tahoma, sans-serif;
}
body {
    margin: 0;
    line-height: normal;
}
pre,
.code,
.codeintable,
.example,
.exampleintable,
.literal,
.literalintable,
.path,
.pathintable {
    font-family: Menlo, Consolas, "DejaVu Sans Mono", "Nimbus Mono L", "Lucida Sans Typewriter", "Courier New", Courier, Monaco, monospace;
    margin-top: 1pt;
    margin-bottom: 1pt;
}
.acronym {
    font-weight: bold;
}
.related {
    font-weight: bold;
    margin-top: 20pt;
    border-top: 1px solid black;
}
.emph,
.menuitem,
.keycode {
    font-weight: bold;
}
.tablehead,
.tableheadintable {
    font-weight: bold;
    margin-top: 0px;
    background: #CCF4C6;
    text-align: center;
}
.howtogetheader {
    font-weight: bold;
    border: 1px solid #999999;
    background: #FFFFFF;
    padding: 3px;
}
h1,
h2,
h3,
h4,
h5,
h6 {
    margin-bottom: 8pt;
    color: #18A303;
}
p,
td {
    font-size: 11pt;
    margin: 2px 2px 2px 2px;
}
h1 {
    font-size: 22pt;
    font-weight: 300;
    border-bottom: 3px solid #18A303;
    padding-bottom: 6px;
}
h2 {
    font-size: 14pt;
}
h3 {
    font-size: 12pt;
}
h4,
h5,
h6 {
    font-size: 11pt;
}
.avis {
    /*    background-color: #EEEEEE;*/
}
.relatedtopics {
    font-weight: normal;
}
.relatedbody {
    margin-top: 2px;
    margin-bottom: 2px;
    margin-left: 5px;
}
.howtoget {
    background: #CCF4C6;
}
.howtogetbody {
    background: #CCF4C6;
    margin: 0px;
}
.wide {
    width: 100%;
}
.topalign {
    vertical-align: top;
    border: 1px;
}
.bug {
    color: red;
}
.debug {
    border: 1px solid black;
    padding: 3px;
    display: show;
    background-color: #222;
    color: red;
    text-align: left;
}
.bascode {
    background-color: #fafafa;
    margin-left: 30px;
    margin-right: 30px;
}
/* Basic code syntax highlight */

.identifier,
.unknown {
    color: green;
}
.keyword {
    color: blue;
}
.comment {
    color: gray;
}
.number,
.string {
    color: red;
}
.operator,
.parameter {
    color: black;
}
.hotlink {
    color: blue;
}
.infopage {
    color: green;
    font-size: 16pt;
    font-weight: bold;
}
.topmenu {
    font-size: 12pt;
    font-weight: bold;
    padding: 1px;
    border: solid 1px #18A303;
}
#DisplayArea {
    overflow: auto;
    padding: 10px;
    grid-area: main;
}
.mediabutton {
    background-color: cyan;
}
.tintro {
    color: white;
    background-color: green;
    font-family: Arial;
    font-weight: bold;
    font-size: 24pt;
    border: 1px solid black;
    padding-bottom: 6px;
    margin-bottom: 6px;
}
.embedded {}
header {
    background-color: #18A303;
    color: #fff;
    height: 4em;
    padding: .5em .5em .5em 1em;
    flex-wrap: wrap;
    justify-content: space-between;
    grid-area: header;
}
.logo {
    flex-shrink: 0;
    color: #fff;
    text-decoration: none;
    float: left;
    width: 190px;
}
.logo p {
    font-size: 1.5em;
    width: 130px;
    float: left;
}
.logo .symbol {
    background-image: url(media/navigation/libo-symbol-white.svg);
    background-repeat: no-repeat;
    background-size: contain;
    width: 3em;
    height: 3.7em;
    float: left;
    margin-right: .5em;
}
header nav {
    margin-top: .7em;
    padding: 0;
    display: none;
    border: 1px solid;
    position: relative;
}
/* Create a style for the first level items */

header nav a {
    color: #333333;
    background-color: #EEEEEE;
    display: block;
    line-height: 1.5em;
    padding: 0.2em 0.4em;
    text-decoration: none;
    font-weight: bold;
    border-width: 0 1px 0 0;
    border-style: solid;
    border-color: #333333;
    font-size: 1.5em;
    flex-shrink: 0;
    z-index: 100;
    white-space: nowrap;
}

header nav a:last-child {
    border-right-width: 0;
}

header label {
    cursor: pointer;
    font-size: 1.2em;
    position: relative;
    top: 2em;
    float: right;
}
header input[type="checkbox"]:checked ~ nav {
    background: #f1f1f1;
    color: #444;
    z-index: 100;
    /* line them up horizontally */

    display: flex;
    flex-direction: row;
    /* allow for scrolling */

    overflow-x: auto;
    overflow-y: hidden;
    /* make it smooth on iOS */

    -webkit-overflow-scrolling: touch;
    clear: both;
    text-align: center;
}
footer {
    background: #18A303;
    color: #fff;
    padding: .1em 3em;
    text-align: center;
    grid-area: footer;
}
footer a {
    color: #c2f6ba;
}
.breadcrumbs ul {
    list-style-type: none;
    margin: 0;
    padding: 0;
    color: #333;
}
.breadcrumbs li {
    display: inline-block;
    position: relative;
    padding-right: 2em;
    margin: 0;
}
.breadcrumbs li:after {
    content: '>';
    position: absolute;
    display: inline-block;
    right: 0;
    width: 2em;
    text-align: center;
}
.breadcrumbs li:last-child {
    font-weight: bold;
}
.breadcrumbs li:last-child:after {
    content: '';
}
.breadcrumbs a {
    text-decoration: none;
    display: inline-block;
    color: #333;
    white-space: nowrap;
}
.breadcrumbs a:hover {
    text-decoration: underline;
}
.accordion {
    margin: 0 auto;
    width: 100%;
    height: 100%;
    list-style-type: none;
    grid-area: accordion;
}
.acc-panel > div {
    display: none;
}
header input[type=checkbox],
.contents-treeview input[type=checkbox] {
    position: absolute;
    opacity: 0;
}
.accordion input[type=checkbox] {
    display: none;
}
.acc-panel > label {
    color: #666;
    cursor: pointer;
    display: block;
    font-size: 1em;
    height: 2.5em;
    line-height: 2.5em;
    padding: 0 1.5em;
    text-align: center;
}
.acc-panel:nth-of-type(1) > label {
    background: #E7FDE4;
}
.acc-panel:nth-of-type(2) > label {
    background: #F7FEE5;
}
.acc-panel:nth-of-type(3) > label {
    background: #E2FBF8;
}
.acc-panel > label:hover {
    color: #222;
}
.acc-panel:nth-of-type(1) > label:hover {
    background: #D5FACF;
}
.acc-panel:nth-of-type(2) > label:hover {
    background: #F0FDD2;
}
.acc-panel:nth-of-type(3) > label:hover {
    background: #CAF4F0;
}
.accordion input[type=checkbox]:checked + label + div {
    background: #f1f1f1;
    color: #444;
    z-index: 6;
    display: block;
}
#Index div#SearchBox {
    background-color: #c2f6ba;
    line-height: 2em;
    border: 1px solid #18A303;
    vertical-align: center;
    text-align: center;
    top: 2px;
    left: 2px;
}
#Index ul {
    padding-left:15px;
}
#Index ul li {
    list-style-type: none;
    font-size: 11pt;
}
#Index p {
    font-size: 16pt;
    font-weight: bold;
}
#search-bar {
    max-width: 90%;
}
.modules {
    margin: 0;
    padding: 1em;
    overflow: hidden;
    grid-area: modules;
}
.modules ul {
    margin: 0;
    padding: 0;
    display: flex;
    flex-wrap: wrap;
    justify-content: space-around;
}
.modules ul li {
    float: left;
    list-style-type: none;
}
/* Create a style for the first level items */

.modules > ul > li > a {
    color: #000;
    display: block;
    line-height: 1.5em;
    padding: 0.5em 0.5em;
    text-decoration: none;
    font-weight: bold;
    font-size: 11pt;
    float: left;
}
.modules div {
    background-repeat: no-repeat;
    background-size: contain;
    float: left;
}
.calc,
.chart,
.writer,
.impress,
.draw,
.math,
.basic,
.base {
    width: 21.5px;
    height: 26px;
    position: relative;
    top: -8px;
    margin-right: 5px;
}
.calc {
    background-image: url(media/navigation/libo-calc.svg);
}
.writer {
    background-image: url(media/navigation/libo-writer.svg);
}
.impress {
    background-image: url(media/navigation/libo-impress.svg);
}
.draw {
    background-image: url(media/navigation/libo-draw.svg);
}
.math {
    background-image: url(media/navigation/libo-math.svg);
}
.base {
    background-image: url(media/navigation/libo-base.svg);
}
.chart {
    background-image: url(media/navigation/libo-chart.svg);
}
.basic {
    background-image: url(media/navigation/libo-basic.svg);
}
/* tree view */

.contents-treeview ul,
.contents-treeview li {
    padding: 0;
    margin: 0;
    list-style: none;
    font-size: 11pt;
}
.contents-treeview {
    /*    font: normal 11px "Segoe UI", Arial, Sans-serif;*/

    -moz-user-select: none;
    -webkit-user-select: none;
    user-select: none;
}
.contents-treeview a {
    /*     color: #00f; */

    text-decoration: none;
}
.contents-treeview a:hover {
    text-decoration: underline;
}
.contents-treeview input + label + ul {
    margin: 0 0 0 22px;
}
.contents-treeview input ~ ul {
    display: none;
}
.contents-treeview label,
.contents-treeview label::before {
    cursor: pointer;
    background: url("media/icon-themes/res/folderop.png") no-repeat;
    color: #111;
}
.contents-treeview input:disabled + label {
    cursor: default;
    opacity: .6;
}
.contents-treeview input:checked:not(:disabled) ~ ul {
    display: block;
}
.contents-treeview label,
.contents-treeview a,
.contents-treeview label::before {
    height: 16px;
    line-height: 16px;
    vertical-align: middle;
}
.contents-treeview label {
    background-position: 18px 0;
}
.contents-treeview label::before {
    content: "";
    width: 16px;
    margin: 0 22px 0 0;
    background-position: 0 -32px;
    display: inline-block;
}
.contents-treeview input:checked + label::before {
    background-position: 0 -16px;
}
/* webkit adjacent element selector bugfix */

@media screen and (-webkit-min-device-pixel-ratio: 0) {
    .contents-treeview {
        -webkit-animation: webkit-adjacent-element-selector-bugfix infinite 1s;
    }
    @-webkit-keyframes webkit-adjacent-element-selector-bugfix {
        from {
            padding: 0;
        }
        to {
            padding: 0;
        }
    }
}
@media screen and (min-width: 960px) {
    body {
        max-width: 1024px;
        margin: auto;
    }
    header nav a {
        font-size: 1em;
        white-space: normal;
        border-width: 0 0 1px 0;
    }
    header nav a:last-child {
        border-bottom-width: 0;
    }
    /* change the language menu direction to stacked */

    header input[type="checkbox"]:checked ~ nav {
        flex-direction: column;
        max-width: 7.5em;
        float: right;
        overflow-y: auto;
        max-height: 30em;
    }
    .accordion {
        display: flex;
        width: 960px;
    }
    .acc-panel {
        flex-basis: 320px;
    }
    .acc-panel > label {
        margin-right: .25em;
    }
    .accordion input[type=checkbox]:checked + label + div {
        max-width: 316px;
    }
    #search-bar {
        max-width: 290px;
    }
}
@supports (grid-area: auto) {
    @media screen and (min-width: 960px) {
        body {
            display: grid;
            grid-template-columns: 320px 1fr;
            grid-template-rows: 1fr minmax(1em, auto);
            grid-template-areas: "header header"
                                 "modules modules"
                                 "accordion accordion"
                                 "main main"
                                 "footer footer";
        }
    }
}
